#ifndef RASTER_CONTROL_H_
#define RASTER_CONTROL_H_
#include "clut_t.h"

//
// setup and configurization of the rasterizer.
//
// As no internal resources are allocated, 
// no shut-down is necessary.
// (other than unloading the dll/lib of course) 
//


//
// note: to view this document properly, tab indents
// shoule be set to 1 (one) character.
//


//
// uncomment this line if you are operating in
// single precision mode outside of the rasterizer.
//
// #define FP_SINGLE_PRES



//
// raster
//
namespace raster
{
  
//
// Specifies the display properties of the output device (be it a RAM frame buffer or video memory).
// The display is assumed to be 16 bit rgb.
//
 extern void __fastcall set_display_16(const clut_miser::pixel_format_16 & desc );

 //
 // Specifies the display properties of the output device (be it a RAM frame buffer or video memory).
 // The display is assumed to be 8 bit palettized.
 //
 // If blend_table is 0, translucent polys cannot be drawn.
 // Otherwise, this table must have been generated by 
 // clut_miser for the current video palette.

 extern void __fastcall set_display_8( const clut_miser::pixel_blend_table_8 * blend_table );

 //
 // one of these functions must be called before any drawing is performed.
 //
 // These functions have the following effects each time they are called:
 //  Sets internal static variables and function pointers based on current frame buffer settings.
 // 
 // The first time that one of these functions is called it will have the following additional effects:
 //  Assigns read/write access to certain code segments to allow the use of source code variables
 //  Initializes internal static tables that are independent of display mode.

  


  //
  // turns on or off edge clipping for polys
  //
  extern void __fastcall set_edge_clipping(int do_clipping);



  //
  // sets the dimension of the blocks used by the perspective texturer
  // valid numbers are 4,8 and 16.
  // 16 is usually enough in 640x480, but things might get jaggy when 
  // dz/dx or dz/dy gets really big
  //
  extern void __fastcall set_persp_block_dim(int _dim);


  //
  // sets the clut index used as the transparent color for all textures.
  // the default value is 0.
  extern void __fastcall set_transparency_index(byte index);


  extern float haze_far_z_inv;  // for perspective polys, the shade is multiplied by
                            // (1.0 - z*haze_far_z_inv)
                            // if you are using a far clip plane you should
                            // probably set this value to 
                            // 1.0 / far_z
   

  extern float block_dim_8_min_distance;  // maximum distance to line of infinite z in screen pixels
                                          // for which the 8x8 perspective block dims can be used
                                          // anything closer uses 4x4
  extern float block_dim_16_min_distance;  // same for 16x16 to be used

  
};



#endif
